
ownip
===========


ownip is a thin wrapper on top of the [MYIP-API](https://api.myip.com). 


To Start...
-----------

To install ownip:

```bash
pip install ownip
```


Using it...
-----------

```python
import ownip

print(ownip.get())
```



Changelog
---------

v1.0.1- 28/08/2022

~~~~~~~~~~~~~~~~~
First Release :)
